==> executable-war-0.1.1-src.zip: executable-war-0.1.1/src/main/resources/archetype-resources/jar/src/main/java/Start.java <==
import java.io.File;
import java.net.JarURLConnection;
import java.net.URL;
import org.apache.derby.jdbc.EmbeddedDataSource;
import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.plus.naming.Resource;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.webapp.WebAppContext;

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

/**
 * TODO fix or dead!
 * @author seiji
 */
public class Start {

    public static void main(String[] args) {
        try {
            Server server = new Server();
            Connector connector = new SelectChannelConnector();
            connector.setPort(8080);
            server.addConnector(connector);

            // DataSourceを登録する
            EmbeddedDataSource ds = new EmbeddedDataSource();
            ds.setCreateDatabase("true");
            ds.setDataSourceName("embedded");
            ds.setDatabaseName(System.getProperty("user.home") + "/data/${groupId}/${artifactId}/db;create=true");
            Resource resource = new Resource("jdbc/${artifactId}ds", ds);

            // 自分のはいっているWARファイル名を取得する
            URL url = Start.class.getClassLoader().getResource("Start.class");
            File warFile = new File(((JarURLConnection) url.openConnection()).getJarFile().getName());


            WebAppContext context = new WebAppContext(warFile.getAbsolutePath(), "/${artifactId}");

            server.setHandler(context);


            server.start();
            server.join();

        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}

==> executable-war-0.1.2-src.zip: executable-war-0.1.2/src/main/resources/archetype-resources/jar/src/main/java/Start.java <==

import java.io.File;
import java.net.JarURLConnection;
import java.net.URL;
import org.apache.derby.jdbc.EmbeddedDataSource;
import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.plus.naming.Resource;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.webapp.WebAppContext;

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
/**
 * TODO fix or dead!
 * @author seiji
 */
public class Start {

    public static void main(String[] args) {
        try {
            Server server = new Server();
            Connector connector = new SelectChannelConnector();
            connector.setPort(8080);
            server.addConnector(connector);

            // DataSourceを登録する
            EmbeddedDataSource ds = new EmbeddedDataSource();
            ds.setCreateDatabase("true");
            ds.setDataSourceName("embedded");
            ds.setDatabaseName(System.getProperty("user.home") + "/data/${groupId}/${artifactId}/db;create=true");
            Resource resource = new Resource("jdbc/${artifactId}ds", ds);

            // 自分のはいっているWARファイル名を取得する
            URL url = Start.class.getClassLoader().getResource("Start.class");
            File warFile = new File(((JarURLConnection) url.openConnection()).getJarFile().getName());


            WebAppContext context = new WebAppContext(warFile.getAbsolutePath(), "/${artifactId}");

            context.setConfigurationClasses(new String[]{
                    "org.mortbay.jetty.webapp.WebInfConfiguration",
                    "org.mortbay.jetty.plus.webapp.EnvConfiguration",
                    "org.mortbay.jetty.plus.webapp.Configuration",
                    "org.mortbay.jetty.webapp.JettyWebXmlConfiguration",
                    "org.mortbay.jetty.webapp.TagLibConfiguration"
                });

            server.setHandler(context);


            server.start();
            server.join();

        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}
